@@ -552,23 +552,26 @@ class ExecutionServer(BaseServer):
             LOGGER.critical("No average speed to report yet.")
             
     def executeJobs(self, data=None):
-        while len(self.job_queue) > 0 and len(self.active_jobs) < self.simultaneous_jobs:
-            job = self.job_queue.pop(0)
+        for i in range(0, 10):            
+            if len(self.job_queue) > 0 and len(self.active_jobs) < self.simultaneous_jobs:
+                job = self.job_queue.pop(0)
+                exposed_function = job["exposed_function"]
+                kwargs = job["kwargs"]
+                function_name = job["function_name"]
+                uuid = job["uuid"]
+                del self.queued_jobs[uuid]
+                LOGGER.debug("Calling %s with args %s" % (function_name, kwargs))
+                self._callExposedFunction(
+                    exposed_function["function"],
+                    exposed_function["interval"], 
+                    kwargs, 
+                    function_name, 
+                    uuid=uuid,
+                    reservation_fast_cache=job["reservation_cache"])
+            else:
+                return
+        reactor.callLater(.1, self.executeJobs)
             
-            exposed_function = job["exposed_function"]
-            kwargs = job["kwargs"]
-            function_name = job["function_name"]
-            uuid = job["uuid"]
-            del self.queued_jobs[uuid]
-            LOGGER.debug("Calling %s with args %s" % (function_name, kwargs))
-            self._callExposedFunction(
-                exposed_function["function"],
-                exposed_function["interval"], 
-                kwargs, 
-                function_name, 
-                uuid=uuid,
-                reservation_fast_cache=job["reservation_cache"])
-
     def _callExposedFunction(
         self, 
         func, 
@@ -577,17 +580,15 @@ class ExecutionServer(BaseServer):
         function_name, 
         uuid=None, 
         reservation_fast_cache=None):
-        d = maybeDeferred(self._jobCountCallback)
+        d = self.callExposedFunction(
+            func, 
+            kwargs, 
+            function_name, 
+            uuid=uuid,
+            reservation_fast_cache=reservation_fast_cache)
+        d.addCallback(self._jobCountCallback)
+        d.addErrback(self._jobCountErrback)
         d.addCallback(self._setNextRequest, uuid, interval, function_name)
-        #d = self.callExposedFunction(
-        #    func, 
-        #    kwargs, 
-        #    function_name, 
-        #    uuid=uuid,
-        #    reservation_fast_cache=reservation_fast_cache)
-        #d.addCallback(self._jobCountCallback)
-        #d.addErrback(self._jobCountErrback)
-        #d.addCallback(self._setNextRequest, uuid, interval, function_name)
         
     def _jobCountCallback(self, data=None):
         self.job_count += 1
